Module request

Module request 

This module contains the structs that are used to make a request to the API. Here we define the Request struct and the RequestBuilder struct, which are the center of the custom request system.

Modules

attributes
filter
pagination
sort

Structs

Request
This struct represents a request to the API. It should be created with the RequestBuilder.
RequestBuilder
This struct is used to build a Request.

Traits

GetUrl
This trait is implemented by all structs that can be used to make a request to the API. It is used to get the url for the request.